@@ -8,9 +8,10 @@
 #' Given that this returns a \pkg{ggplot2} object, you can modify the plot by
 #' adding \pkg{ggplot2} layers (see example).
 #' @param ... any number of [kwic][quanteda::kwic] class objects
-#' @param scale whether to scale the token index axis by absolute position of
-#'   the token in the document or by relative position. Defaults are absolute
-#'   for single document and relative for multiple documents.
+#' @param scale `"relative"` or `"absolute"`: whether to scale the token index
+#'   axis by absolute position of the token in the document or by relative
+#'   position. Defaults are `"absolute"` for single document and `"relative"`
+#'   for multiple documents.
 #' @param sort whether to sort the rows of a multiple document plot by document
 #'   name
 #' @return a \pkg{ggplot2} object
@@ -113,6 +114,7 @@ textplot_xray.kwic <- function(..., scale = c("absolute", "relative"),
         x$from <- x$from / x$ntokens
 
     from <- ntokens <- NULL
+    max_ntokens <- max(x$ntokens)
     plot <- ggplot2::ggplot(x, ggplot2::aes(x = from, y = 1)) +
         ggplot2::geom_segment(ggplot2::aes(xend = from, yend = 0)) +
         ggplot2::theme(axis.line = ggplot2::element_blank(),
@@ -129,7 +131,7 @@ textplot_xray.kwic <- function(..., scale = c("absolute", "relative"),
 
     if (scale == "absolute")
         plot <- plot +
-          ggplot2::geom_rect(ggplot2::aes(xmin = ntokens, xmax = max(x$ntokens),
+          ggplot2::geom_rect(ggplot2::aes(xmin = ntokens, xmax = max_ntokens,
                                           ymin = 0, ymax = 1), fill = "gray90")
 
     if (multiple_documents) {
